# array2tree

![](https://travis-ci.org/lihang90/array2tree.svg?branch=master)
[![Coverage Status](https://coveralls.io/repos/github/lihang90/array2tree/badge.svg?branch=master)](https://coveralls.io/github/lihang90/array2tree?branch=master)
[![npm](https://img.shields.io/npm/v/array2tree.svg)](https://www.npmjs.com/package/array2tree)
![npm](https://img.shields.io/npm/dm/array2tree.svg)

![](https://nodei.co/npm/array2tree.png?downloads=true)


转换一维数组为一棵树，数组子项通过id和pid做父级与子级的关联。常用于生成树状菜单<br/>

你也可以自定义父子关联关系的字段名，默认为id与pid关联。


例如：
```javascript
[
    {
        id: 1,
        pid: 0,
        name: 'level 1'
    },
    {
        id: 2,
        pid: 1,
        name: 'level 2'
    }
    ...
]
```

转换为：

```javascript
[{
    id: 1,
    pid: 0,
    name: 'level 1',
    children: [
        {
            id: 2,
            pid: 1,
            name: 'level 2',
            children: [...]
        }
    ]
},...]
```

## 如何使用？

* 你可以使用npm安装
```
$ npm install array2tree --save
```

* 安装完成后在你的代码处使用
```javascript
const array2tree = require('array2tree');

const testArr = [
    {
        id: 1,
        pid: 0,
        name: 'level 1'
    },
    {
        id: 2,
        pid: 1,
        name: 'level 2'
    },
    {
        id: 3,
        pid: 2,
        name: 'level 3'
    }
];

const tree = array2tree(testArr);

console.log(tree);
/*
    [{
        id: 1,
        pid: 0,
        name: 'level 1',
        children: [
            {
                id: 2,
                pid: 1,
                name: 'level 2',
                children: [
                    {
                        id: 3,
                        pid: 2,
                        name: 'level 3',
                        children: []
                    }
                ]
            }
        ]
    }]
*/
```

* 使用自定义关联关系字段，例子展示为myId与parentId关联
```javascript
const array2tree = require('array2tree');

const testArr = [
    {
        myId: 1,
        parentId: 0,
        name: 'level 1'
    },
    {
        myId: 2,
        parentId: 1,
        name: 'level 2'
    },
    {
        myId: 3,
        parentId: 2,
        name: 'level 3'
    }
];

const tree = array2tree(testArr, 'myId', 'parentId');

console.log(tree);
/*
    [{
        myId: 1,
        parentId: 0,
        name: 'level 1',
        children: [
            {
                myId: 2,
                parentId: 1,
                name: 'level 2',
                children: [
                    {
                        myId: 3,
                        parentId: 2,
                        name: 'level 3',
                        children: []
                    }
                ]
            }
        ]
    }]
*/
```

## 如何测试？

```
$ npm install && npm test
```